-- stream.lua
local utl = require "luci.util"
local sys = require "luci.sys"
local uci = require("luci.model.uci").cursor()

local DEVICE_TYPE = 'Router'

function restart(r)
   local deviceId = r:value(2)
   c8y:send('108,'..deviceId..',SUCCESSFUL')
   sys.exec("reboot")
end

function sysupgrade(r)
   local deviceId = r:value(2)
   local url = r:value(3)
   local username = uci:get("cot", "cumulocity", "username")
   local password = uci:get("cot", "cumulocity", "password")
   c8y:send('108,'..deviceId..',EXECUTING')
   sys.exec("/usr/bin/curl -u '"..username.."':'"..password.."' -o /tmp/cot_firmware.bin "..url)
   local result = sys.exec("/sbin/fw_validate.sh /tmp/cot_firmware.bin | grep 'IMAGE_SUPPORTED=1' | wc -l")
   if tonumber(result) == 1 then
      c8y:send('108,'..deviceId..',SUCCESSFUL')
      sys.exec("/sbin/sysupgrade /tmp/cot_firmware.bin")
   else
      c8y:send('108,'..deviceId..',FAILED')
      sys.exec("rm -rf /tmp/cot_firmware.bin 2> /dev/null")
   end
end

function init()
   local DEVICE_NAME = uci:get("system", "system", "routername")
   local INTERVAL = uci:get("cot", "cumulocity", "interval")
   srInfo('*** Stream Init ***')

   -- set device name and type
   c8y:send('103,'..c8y.ID..','..DEVICE_NAME..','..DEVICE_TYPE)
   c8y:send('111,'..c8y.ID..','..INTERVAL)

   -- set imei, cellid and iccid first time
   mobileDataStream()

   -- create timer which will stream mobile info data
   local m_timer = c8y:addTimer(10 * 1000, 'mobileDataStream')
   m_timer:start()   

   -- register restart handler
   c8y:addMsgHandler(502, 'restart')
   c8y:addMsgHandler(503, 'sysupgrade')
   return 0
end

function mobileDataStream()
   local sign = utl.trim(sys.exec("gsmctl -q"))

   -- send mobile signal info
   c8y:send('105,'..c8y.ID..','..sign)

   local wantype = utl.trim(sys.exec("/usr/bin/wan_info state"))
   local wanip = utl.trim(sys.exec("/usr/bin/wan_info ip"))
  
   -- send wan info
   c8y:send('106,'..c8y.ID..','..wanip..','..wantype)
end
